summaryrefslogtreecommitdiff
path: root/include/tablet_mode.h
diff options
context:
space:
mode:
authorPhilip Chen <philipchen@google.com>2019-08-15 18:24:22 -0700
committerCommit Bot <commit-bot@chromium.org>2019-09-19 03:47:09 +0000
commit0beadf2ffd8b23e15d1e7c14de8719d0f45c9519 (patch)
tree9b531ef5087e3935542560a4bc9b7cc379c3e843 /include/tablet_mode.h
parent16d2b24ac05f7a5654bddcf9cb61f0f6684d1806 (diff)
downloadchrome-ec-0beadf2ffd8b23e15d1e7c14de8719d0f45c9519.tar.gz
tablet_mode: Renaming for GMR sensor
GMR sensors can be used to (1) detect clamshell/tablet mode (2) detect lid open/closed But hall sensors can only do (2). Therefore the naming related to "hall sensor" for tablet mode application is incorrect. This patch performs the following renaming to better reflect the reality: config: CONFIG_HALL_SENSOR -> CONFIG_GMR_TABLET_MODE CONFIG_HALL_SENSOR_CUSTOM -> CONFIG_GMR_TABLET_MODE_CUSTOM CONFIG_DPTF_MOTION_LID_NO_HALL_SENSOR -> CONFIG_DPTF_MOTION_LID_NO_GMR_SENSOR GPIO: HALL_SENSOR_GPIO_L -> GMR_TABLET_MODE_GPIO_L functions: hall_sensor_disable() -> gmr_tablet_switch_disable() hall_sensor_isr() -> gmr_tablet_switch_isr() hall_sensor_int() -> gmr_tablet_switch_init() variable: hall_sensor_at_360 -> gmr_sensor_at_360 BUG=b:139378190 BRANCH=none TEST=make buildall Change-Id: I28393d056ddd128d8ffafc16a1f9fefee5455ccc Signed-off-by: Philip Chen <philipchen@google.com> Reviewed-on: https://chromium-review.googlesource.com/c/chromiumos/platform/ec/+/1757275 Reviewed-by: Furquan Shaikh <furquan@chromium.org> Reviewed-by: Aseda Aboagye <aaboagye@chromium.org> Commit-Queue: Philip Chen <philipchen@chromium.org> Tested-by: Philip Chen <philipchen@chromium.org>
Diffstat (limited to 'include/tablet_mode.h')
-rw-r--r--include/tablet_mode.h22
1 files changed, 11 insertions, 11 deletions
diff --git a/include/tablet_mode.h b/include/tablet_mode.h
index 8ada6cdaf5..b5a2f2f562 100644
--- a/include/tablet_mode.h
+++ b/include/tablet_mode.h
@@ -26,26 +26,26 @@ void tablet_set_mode(int mode);
void tablet_disable(void);
/**
* Interrupt service routine for hall sensor.
*
- * HALL_SENSOR_GPIO_L must be defined.
+ * GMR_TABLET_MODE_GPIO_L must be defined.
*
* @param signal: GPIO signal
*/
-void hall_sensor_isr(enum gpio_signal signal);
+void gmr_tablet_switch_isr(enum gpio_signal signal);
/**
* Disables the interrupt on GPIO connected to hall sensor. Additionally, it
* disables the tablet mode switch sub-system and turns off tablet mode. This is
* useful when the same firmware is shared between convertible and clamshell
* devices to turn off hall sensor and tablet mode detection on clamshell.
*/
-void hall_sensor_disable(void);
+void gmr_tablet_switch_disable(void);
/**
* This must be defined when CONFIG_HALL_SENSOR_CUSTOM is defined. This allows
* a board to override the default behavior that determines if the 360 sensor is
* active: !gpio_get_level(HALL_SENSOR_GPIO_L).
*
* Returns 1 if the 360 sensor is active; otherwise 0.
*/
@@ -26,26 +26,26 @@ void tablet_set_mode(int mode);
void tablet_disable(void);
/**
- * Interrupt service routine for hall sensor.
+ * Interrupt service routine for gmr sensor.
*
@@ -26,26 +26,26 @@ void tablet_set_mode(int mode);
/**
- * Disables the interrupt on GPIO connected to hall sensor. Additionally, it
- * disables the tablet mode switch sub-system and turns off tablet mode. This is
- * useful when the same firmware is shared between convertible and clamshell
- * devices to turn off hall sensor and tablet mode detection on clamshell.
+ * Disables the interrupt on GPIO connected to gmr sensor. Additionally, it
+ * disables the tablet mode switch sub-system and turns off tablet mode. This
+ * is useful when the same firmware is shared between convertible and clamshell
+ * devices to turn off gmr sensor's tablet mode detection on clamshell.
*/
@@ -26,26 +26,26 @@ void tablet_set_mode(int mode);
/**
- * This must be defined when CONFIG_HALL_SENSOR_CUSTOM is defined. This allows
- * a board to override the default behavior that determines if the 360 sensor is
- * active: !gpio_get_level(HALL_SENSOR_GPIO_L).
+ * This must be defined when CONFIG_GMR_TABLET_MODE_CUSTOM is defined. This
+ * allows a board to override the default behavior that determines if the
+ * 360 sensor is active: !gpio_get_level(GMR_TABLET_MODE_GPIO_L).
*
* Returns 1 if the 360 sensor is active; otherwise 0.